@@ -17,7 +17,10 @@ from av.audio.format import AudioFormat
 from av.audio.frame import AudioFrame
 from av.audio.layout import AudioLayout
 from av.audio.resampler import AudioResampler
+from av.codec.codec import Codec, codecs_available
+from av.codec.context import CodecContext
 from av.container import open
+from av.format import ContainerFormat, formats_available
 from av.utils import AVError
 from av.video.format import VideoFormat
 from av.video.frame import VideoFrame
